package de.unikoblenz.fgbks.core.dmn.domain.vdmn;

import de.unikoblenz.fgbks.core.dmn.domain.common.RowNumber;
import de.unikoblenz.fgbks.core.dmn.domain.ids.RuleId;
import java.util.List;
import org.camunda.bpm.model.dmn.instance.Rule;

/**
 * This interface represents a single rule (or row) in a {@link VDmnDecisionTable}. A rule contains
 * a list of {@link VDmnInputValue}s and a list of {@link VDmnOutputValue}s.
 */
public interface VDmnRule extends VDmnElement {

  /**
   * Get the original Rule.
   *
   * @return the {@link Rule}
   */
  Rule getRule();

  /**
   * Get the {@link RowNumber} of the rule inside the dmn table.
   *
   * @return the {@link RowNumber}.
   */
  RowNumber getRowNumber();

  /**
   * Get the {@link VDmnDecisionTable}.
   *
   * @return the {@link VDmnDecisionTable}.
   */
  VDmnDecisionTable getVDmnDecisionTable();

  /**
   * Get a list of {@link VDmnInputValue}s.
   *
   * @return the list of {@link VDmnInputValue}
   */
  List<VDmnInputValue> getVDmnInputValues();

  /**
   * Get a list of {@link VDmnOutputValue}s.
   *
   * @return the list of {@link VDmnOutputValue}
   */
  List<VDmnOutputValue> getVDmnOutputValues();

  /**
   * Get the {@link RuleId} of the {@link VDmnRule}.
   *
   * @return the {@link RuleId}.
   */
  default RuleId getRuleId() {
    return (RuleId) getId();
  }

  /**
   * Get the {@link VDmnDecision}.
   *
   * @return the {@link VDmnDecision}.
   */
  default VDmnDecision getVDmnDecision() {
    return getVDmnDecisionTable().getVDmnDecision();
  }

  /**
   * Get the {@link VDmnDefinitions}.
   *
   * @return the {@link VDmnDefinitions}.
   */
  default VDmnDefinitions getVDmnDefinition() {
    return getVDmnDecision().getVDmnDefinition();
  }
}
